;*****************************************************************************
;* Programm:     DOWN.ASC
;* Controller:   68HC11A1
;* Anwendung:    Dieses Programm ist zum Downloaden von
;*               Software in ein Flash (erst ein Anfang...)
;*
;* Autor:    N. Springob
;* Datum:    14.01.2000
;*****************************************************************************
;*
;*       Initialisierung
;*
;*****************************************************************************

;*****************************************************************************
    PADDING OFF
    ORG $F000
VERS:
    DC.B "$VER: 0.01 - 14.01.2000  CI-Downloader\n"
    DC.B "assembled: ",DATE," ",TIME,"\n"
    DC.B "(c)2000 by Nils Springob\n",0

;*****************************************************************************

            INCLUDE "reg6811.inc"
RG_BAS      EQU $6000               ;Basisadresse f. Indizierte Adressierung

RAM_START   EQU $2000
ROM_START   EQU $F800

STACK       EQU RAM_START+$4FF

RAM_END     EQU RAM_START+$20
ROM_END     EQU ROM_START+$500


    INCLUDE "flash.inc"
    INCLUDE "bank.inc"


;*********** RAM ************
    ORG RAM_START        ;Anfang des RAMs

;*********** ROM ************
    ORG ROM_START        ;Anfang des EPROMs/RAMs
    JMP BEGIN               ;Sprung zum Start

;*****************************************************************************
;*
;*       Init - Initialisierung
;*
;*****************************************************************************
BEGIN:
    LDAA #$36
    STAA $1000+INIT         ;Register auf $6000 setzen, RAM auf $3000

    LDAA #%00010011
    STAA RG_BAS+OPTION

    LDX #RAM_START          ;RAM loeschen
    LDAA #$00
RAM_CLEAR:
    STAA 0,X
    INX
    CPX #RAM_END
    BNE RAM_CLEAR

    LDX #STACK
    TXS

    LDX #RG_BAS             ;RealTimer aktivieren
    BCLR TFLG2,X #%10111111
    LDAA #%01000000
    STAA TMSK2,X

    LDAA #%10000000         ;Port A7 ->Ausgang
    STAA PACTL,X            ;RTI: 4.10 ms
    LDAA #$00
    STAA PORTA,X            ;Ausgaenge PortA auf 0

    LDAA #%00000000         ;X-Bit lschen...
    TAP                     ;ConditionCodeRegister

START:
    JMP START

;*****************************************************************************
;*
;*       COP - Watchdog Reset
;*
;*****************************************************************************
COP_INT:
    JMP BEGIN

;*****************************************************************************
;*
;*       TIMER_INT - Timer Interrupt
;*
;*****************************************************************************
TIMER_INT:
    LDX #RG_BAS
    BCLR TFLG2,X #%10111111     ;Timer-Bit loeschen
    RTI

;*****************************************************************************
;*
;*       X msec. verzgern
;*
;*****************************************************************************
DelayXms:
    LDY #280        ;ca. 1ms
XD1msLoop:
    DEY
    BNE XD1msLoop

    LDY #RG_BAS     ;COP beruhigen
    LDAA #$55
    STAA COPRST,Y
    LDAA #$AA
    STAA COPRST,Y

    DEX             ;naechste msec
    BNE DelayXms

    RTS             ;wenn fertich dann fettig

;*****************************************************************************
;*
;*       ERR_INT - Standard InterruptHandler
;*
;*****************************************************************************
    ORG $F200
ERR_INT:
    LDAA #$e0
    RTI

;*****************************************************************************
;*
;*       VEKTORS
;*
;*****************************************************************************
    ORG $FFD4
    FDB $0000

    FDB ERR_INT     ;SCI
    FDB ERR_INT     ;SPI
    FDB ERR_INT     ;PULSE ACCUM INPUT EDGE
    FDB ERR_INT     ;PULSE ACCUM OVERFLOW
    FDB ERR_INT     ;TIMER OVERFLOW
    FDB ERR_INT     ;TIMER OUTPUT COMPARE 5
    FDB ERR_INT     ;TIMER OUTPUT COMPARE 4
    FDB ERR_INT     ;TIMER OUTPUT COMPARE 3
    FDB ERR_INT     ;TIMER OUTPUT COMPARE 2
    FDB ERR_INT     ;TIMER OUTPUT COMPARE 1
    FDB ERR_INT     ;TIMER INPUT CAPTURE 3
    FDB ERR_INT     ;TIMER INPUT CAPTURE 2
    FDB ERR_INT     ;TIMER INPUT CAPTURE 1
    FDB TIMER_INT   ;REAL TIME INT
    FDB ERR_INT     ;IRQ
    FDB ERR_INT     ;XIRQ
    FDB ERR_INT     ;SWI
    FDB ERR_INT     ;ILLEGAL OP-CODE
    FDB ERR_INT     ;COP FAIL
    FDB ERR_INT     ;CLOCK MONITOR
    FDB BEGIN       ;RESET

